###################################################
### chunk number 1: ProteinFormation
###################################################
library(CHNOSZ)
basis("CHNOS+")
species("CSG",c("METVO","METJA"))
species()


###################################################
### chunk number 2: ProteinInfo
###################################################
protein.info()


###################################################
### chunk number 3: ProteinAffinity
###################################################
a <- affinity()
a$values


###################################################
### chunk number 4: ProteinActivities
###################################################
d <- diagram(a,residue=FALSE,do.plot=FALSE)
d$logact


###################################################
### chunk number 5: ResidueInfo
###################################################
residue.info()


###################################################
### chunk number 6: ResidueActivities1
###################################################
d <- diagram(a,do.plot=FALSE)
as.numeric(d$logact)


###################################################
### chunk number 7: ResidueActivities2
###################################################
d <- diagram(a,as.residue=TRUE,do.plot=FALSE)
10^as.numeric(d$logact)


###################################################
### chunk number 8: SulfurSpeciation
###################################################
basis('CHNOS+')
basis('pH',5)
species(c('H2S','S2-2','S3-2','S2O3-2','S2O4-2','S3O6-2','S5O6-2','S2O6-2','HSO3-','SO2','HSO4-'))
species()
a <- affinity(O2=c(-50,-15),T=325,P=350)
par(mfrow=c(2,1))
diagram(a,logact=-2,ylim=c(-30,0),legend.x="topleft",cex.names=0.8)
title(main="Aqueous sulfur speciation, whole formulas")
diagram(a,logact=-2,ylim=c(-30,0),legend.x="topleft",cex.names=0.8,residue=TRUE)
title(main="Aqueous sulfur speciation, residue equivalents")


###################################################
### chunk number 9: ProteinSpeciation
###################################################
organisms <- c("METSC","METJA","METFE","HALJP","METVO","METBU","ACEKI","BACST","BACLI","AERSA")
proteins <- c(rep("CSG",6),rep("SLAP",4))
basis("CHNOS+")
species(proteins,organisms)
a <- affinity(O2=c(-100,-65))
par(mfrow=c(2,1))
diagram(a,ylim=c(-5,-1),legend.x=NULL,residue=FALSE)
title(main="Relative abundances of proteins, whole formulas")
diagram(a,ylim=c(-5,-1),legend.x=NULL)
title(main="Relative abundances of proteins, residue equivalents")


###################################################
### chunk number 10: PredominanceDiagram
###################################################
basis("CHNOS")
species(c("RPOE","RP32","RP54","RPOD"),"ECOLI")
a <- affinity(NH3=c(-10,0,256),O2=c(-80,-70,256))
# the first one uses the default settings
diagram(a,color=NULL)
# different from the first plot
diagram(a,as.residue=TRUE,add=TRUE,col="darkgreen")
# also somewhat different
diagram(a,residue=FALSE,add=TRUE,col="red")
# same as the first plot
d <- diagram(a,mam=FALSE,add=TRUE,col="darkblue")
t1 <- "Sigma factors in E. coli, residue equivalents"
t2 <- "(black/blue), whole formulas (red/green)"
title(main=paste(t1,t2,sep="\n"))


###################################################
### chunk number 11: CVDiagram
###################################################
diagram(a,col="darkblue",color=NULL)
draw.diversity(d,add=TRUE)
title(main="Sigma factors, coefficient of variation")


